# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ostorlab/agent/message/proto/common/x509/x509.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3ostorlab/agent/message/proto/common/x509/x509.proto\x12(ostorlab.agent.message.proto.common.x509\"N\n\x07X509Org\x12\t\n\x01\x43\x18\x01 \x01(\t\x12\t\n\x01O\x18\x02 \x01(\t\x12\n\n\x02OU\x18\x03 \x01(\t\x12\n\n\x02\x43N\x18\x04 \x01(\t\x12\t\n\x01L\x18\x05 \x01(\t\x12\n\n\x02ST\x18\x06 \x01(\t\"1\n\x08Validity\x12\x12\n\nnot_before\x18\x01 \x01(\x04\x12\x11\n\tnot_after\x18\x02 \x01(\x04\"K\n\x0fX509Fingerprint\x12\x1d\n\x15\x66ingerprint_algorithm\x18\x01 \x01(\t\x12\x19\n\x11\x66ingerprint_value\x18\x02 \x01(\t\"=\n\rX509Extension\x12\x0b\n\x03oid\x18\x01 \x01(\t\x12\x10\n\x08\x63ritical\x18\x02 \x01(\x08\x12\r\n\x05value\x18\x03 \x01(\t\"G\n\rX509PublicKey\x12\x1c\n\x14public_key_algorithm\x18\x01 \x01(\t\x12\x18\n\x10public_key_value\x18\x02 \x01(\t\"E\n\rX509Signature\x12\x1b\n\x13signature_algorithm\x18\x01 \x01(\t\x12\x17\n\x0fsignature_value\x18\x02 \x01(\t\"\xc5\x04\n\x08X509Cert\x12\x16\n\x0eversion_number\x18\x01 \x01(\r\x12\x15\n\rserial_number\x18\x02 \x01(\t\x12\x41\n\x06issuer\x18\x03 \x01(\x0b\x32\x31.ostorlab.agent.message.proto.common.x509.X509Org\x12\x44\n\x08validity\x18\x04 \x01(\x0b\x32\x32.ostorlab.agent.message.proto.common.x509.Validity\x12\x42\n\x07subject\x18\x05 \x01(\x0b\x32\x31.ostorlab.agent.message.proto.common.x509.X509Org\x12K\n\npublic_key\x18\x06 \x01(\x0b\x32\x37.ostorlab.agent.message.proto.common.x509.X509PublicKey\x12J\n\tsignature\x18\x07 \x01(\x0b\x32\x37.ostorlab.agent.message.proto.common.x509.X509Signature\x12W\n\x14\x63omputed_fingerprint\x18\x08 \x03(\x0b\x32\x39.ostorlab.agent.message.proto.common.x509.X509Fingerprint\x12K\n\nextensions\x18\t \x03(\x0b\x32\x37.ostorlab.agent.message.proto.common.x509.X509Extension')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ostorlab.agent.message.proto.common.x509.x509_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _X509ORG._serialized_start=97
  _X509ORG._serialized_end=175
  _VALIDITY._serialized_start=177
  _VALIDITY._serialized_end=226
  _X509FINGERPRINT._serialized_start=228
  _X509FINGERPRINT._serialized_end=303
  _X509EXTENSION._serialized_start=305
  _X509EXTENSION._serialized_end=366
  _X509PUBLICKEY._serialized_start=368
  _X509PUBLICKEY._serialized_end=439
  _X509SIGNATURE._serialized_start=441
  _X509SIGNATURE._serialized_end=510
  _X509CERT._serialized_start=513
  _X509CERT._serialized_end=1094
# @@protoc_insertion_point(module_scope)
